@@ -1,65 +1,3 @@
-#######################################################
-## new functions for Rcpp implementation             ##
-#######################################################
-
-createInput <- function(init, object) {
-  if (is(init@pp, "rlmerPredD_Rcpp")) {
-    return(init@pp$input)
-  }
-
-  Lambdat <- getME(init, "Lambdat")
-  Lind <- getME(init, "Lind")
-  b <- findBlocks(Lambdat = Lambdat, Lind = Lind)
-  rho_e_instance <- object@rho.e@getInstanceWithOriginalDefaults();
-  rhoSigma_e_instance <- object@rho.sigma.e@getInstanceWithOriginalDefaults()
-  rho_b_instance <- lapply(object@rho.b, function(x) x@getInstanceWithOriginalDefaults())
-  rhoSigma_b_instance <- lapply(object@rho.sigma.b, function(x) x@getInstanceWithOriginalDefaults())
-  input <- list(Lambdat = Lambdat,
-                lower = getME(init, "lower"),
-                dim = as.integer(b$dim),
-                v_e = weights(init),
-                Lind = as.integer(Lind),
-                ind = as.integer(b$ind),
-                k = as.integer(b$k),
-                idx = b$idx,
-                blockBMap = unlist(unlist(lapply(b$idx, apply, 2, list), recursive = FALSE), recursive = FALSE),
-                thetaBlockMap = lapply(b$blocks, function(b) b[lower.tri(b, diag = TRUE)]),
-                rho_e_src = object@rho.e,
-                rho_e_instance = rho_e_instance,
-                rho_e = rho_e_instance$.pointer,
-                rhoSigma_e_src = object@rho.sigma.e,
-                rhoSigma_e_instance = rhoSigma_e_instance,
-                rhoSigma_e = rhoSigma_e_instance$.pointer,
-                rho_b_src = object@rho.b,
-                rho_b_instance = rho_b_instance,
-                rho_b = lapply(rho_b_instance, function(x) x$field(".pointer")),
-                rhoSigma_b_src = object@rho.sigma.b,
-                rhoSigma_b_instance = rhoSigma_b_instance,
-                rhoSigma_b = lapply(rhoSigma_b_instance, function(x) x$field(".pointer")),
-                theta = getME(init, "theta"),
-                beta = getME(init, "beta"),
-                b.s = getME(init, "u"),
-                sigma = getME(init, "sigma"),
-                ## for DAS
-                maxOperations = 200,
-                relativeTolerance = 1e-6,
-                ## for DAStau
-                nodes = 13
-  )
-  return(input)
-}
-
-convToRlmerPredD <- function(init, object, ...) {
-  input <- createInput(init, object)
-  pp <- do.call(rlmerPredD_Rcpp$new, list(input = input,
-                                          method = object@method,
-                                          X = getME(init, "X"),
-                                          Zt = getME(init, "Zt")))
-  pp
-}
-
-
-
 #######################################################
 ## Functions to generate commonly required objects   ##
 #######################################################
